#
# spec file for package labplot-kf5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           labplot-kf5
Version:        2.3.0
Release:        2.8
Summary:        KDE Framework 5 data analysis and visualization application
License:        GPL-2.0+
Group:          Productivity/Scientific/Other
Url:            https://edu.kde.org/applications/science/labplot/
Source:         http://download.kde.org/stable/labplot/%{version}/labplot-%{version}-kf5.tar.xz
# PATCH-FIX-UPSTREAM fix-desktop-file.patch -- fix the Exec line in the .desktop file so labplot can be started from the application menu
Patch:          fix-desktop-file.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cantor-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hdf5-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KDE4Support)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(muparser)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(zlib)
Provides:       labplot = %{version}
Obsoletes:      labplot < 2.3.0

%lang_package

%description
LabPlot is a KDE application for interactive graphing and analysis
of scientific data. LabPlot provides an easy way to create, manage
and edit plots. It allows you to produce plots based on data from a
spreadsheet or on data imported from external files. Plots can be
exported to several pixmap and vector graphic formats.

This version is based on KDE Frameworks 5

%prep
%setup -q -n labplot-%{version}-kf5
%patch -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
pushd build
%kf5_makeinstall
popd

# appstream-builder vetoes application unless appdata.xml file and .desktop file have matching names
# appdata.xml file references "org.kde.labplot2.desktop" but .desktop file installed as labplot2.desktop
mv %{buildroot}%{_kf5_applicationsdir}/labplot2.desktop %{buildroot}%{_kf5_applicationsdir}/org.kde.labplot2.desktop
mv %{buildroot}%{_kf5_sharedir}/appdata/org.kde.labplot.appdata.xml %{buildroot}%{_kf5_sharedir}/appdata/org.kde.labplot2.appdata.xml

%find_lang labplot2 %{?no_lang_C}

%fdupes -s %{buildroot}

%kf5_post_install

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING README
%{_kf5_bindir}/labplot2
%{_kf5_appsdir}/labplot2/
%{_kf5_applicationsdir}/org.kde.labplot2.desktop
%dir %{_kf5_iconsdir}/hicolor/512x512/
%dir %{_kf5_iconsdir}/hicolor/512x512/apps/
%{_kf5_iconsdir}/hicolor/scalable/apps/labplot-*
%{_kf5_iconsdir}/hicolor/*/apps/labplot2.*
%{_kf5_kxmlguidir}/labplot2/
%{_kf5_sharedir}/mime/packages/labplot2.xml
%dir %{_kf5_sharedir}/appdata/
%{_kf5_sharedir}/appdata/org.kde.labplot2.appdata.xml
%{_kf5_htmldir}/en/labplot2/

%files lang -f labplot2.lang
%defattr(-,root,root,-)
%{_kf5_htmldir}/*/labplot2/
%{_kf5_htmldir}/pt_BR/
## These belong in the main package
%exclude %{_kf5_htmldir}/en/labplot2/

%changelog
* Mon Sep  5 2016 badshah400@gmail.com
- Add Provides: labplot = %%{version} and Obsoletes: labplot <
  2.3.0 to enable easy upgrade from openSUSE Leap 42.1 to 42.2,
  where labplot-kf5 2.3.0 should replace labplot. This assumes
  that the Leap 42.1 labplot (currently at version 2.0.2) itself
  does not get upgraded to a version above 2.3.0 via official
  maintenance updates. Remove Conflicts on labplot as a
  consequence.
* Wed Jul 27 2016 wbauer@tmo.at
- Add fix-desktop-file.patch to fix the Exec line in the .desktop
  file so labplot can be started from the application menu
- Add cantor-devel to the build requires to enable the new cantor
  integration
* Tue Jul 26 2016 wbauer@tmo.at
- Update to version 2.3.0
- New features:
  * Integration of Cantor - Support for different open-source
    computer algebra systems
  * Statistics on spreadsheets and matrices
  * Export of spreadsheets and matrices to LaTeX tables
  * Interpolation of data including different splines, cosine,
    exponential, cubic Hermite (Catmull-Rom, cardinal,
    Kochanek-Bartels) and rational functions
  * Data smoothing using moving average (centered or lagged),
    percentile filter or Savitzky-Golay algorithm
  * Fourier filter (low pass, high pass, band pass, band reject)
    with ideal, Butterworth, Chebychev I+II, Legendre or
    Bessel-Thomson filter
  * Fourier transform with many window functions (Welch, Hann,
    Hamming, etc.) calculating magnitude, amplitude, power, phase,
    dB, etc. and supporting one/two sided spectrum with or without
    shift and x scaling to frequency, index or period
  * Filter and search capabilities in the drop down box for the
    selection of data sources
  * Sigmoid function as a new pre-defined fit model
  * Support for compiling on Microsoft Windows
- Performance improvements:
  * Faster generation of random values
  * Global option to enable/disable the double-buffering for faster
    painting of curves (enabled on default)
- Bug fixes:
  * Save and restore last used setting in RandomValuesDialog
  * Update axis title shape on title rotations correctly
  * Save and restore custom column widths in the spreadsheet
  * Fixed sporadic crashes during project close
- Drop upstreamed labplot-kf5-gcc5-isnan.patch
* Fri Jul 15 2016 badshah400@gmail.com
- Labplot does not show up in application centers (e.g.
  gnome-software) as appstream-builder expects the .appdata.xml
  file and .desktop file to have matching names; rename .desktop
  file to org.kde.labplot2.desktop as referenced in the
  appdata.xml file, and rename appdata.xml file accordingly.
* Sun May  8 2016 badshah400@gmail.com
- Add labplot-kf5-gcc5-isnan.patch: Replace isnan by std::isnan
  to fix building with gcc5.
* Wed May  4 2016 mailaender@opensuse.org
- Update to version 2.2.0
  * Added the DataPicker which converts input graph (images) into numbers.
  * A new custom point was implemented
  * LabPlot now acccepts now drag&drop-events
  * Rendering of the image view of the matrix recieved a speed up
* Wed Oct 28 2015 toddrme2178@gmail.com
- Conflict with labplot, not labplot2.
* Mon Oct 26 2015 toddrme2178@gmail.com
- Initial Frameworks 5 version.
* Mon Oct 26 2015 toddrme2178@gmail.com
- Enable HDF5 and NetCDF support.  Support for these formats is
  considered stable now.
* Mon Oct 26 2015 freitag@owncloud.com
- Fixing build issues by upgrading to new upstream version 2.1.0
- 2.1.0 new features:
  * New Matrix view for handling matrix data.
  * Workbook - a new container for grouping several objects of type
    Spreadsheet and/or Matrix.
  * Import of binary, image, NetCDF and HDF data into spreadsheet or
    matrix.
  * Visual HDF and NetCDF parser to view content of files and import
    data sets.
  * Preview of all supported file types in import dialog.
  * Transparently import compressed data files.
  * In xy-curve the points may not be connected by the line if there
    are NANs in-between. This behaviour is controlled by the parameter
    "skip gaps".
  * Multiplier of Pi format of the plot axis for periodical functions.
  * New operations on columns in Spreadsheet - reverse, drop values
    and mask values.
  * Formula used to generate the values in a column is stored and can
    be changed/adjusted in the formula dialog afterwards.
  * Curve filling: the area below, under, left to or right to the
    curve can be filled.
  * Support for multiple variables in "Function Values"-dialog - new
    data in the spreadsheet can be calculated out of multiple columns.
- Performance improvements:
  * Speeded up the creation of new columns during the import
- Bug fixes:
  * Fixed wrong behaviour when doing "zoom&select" in a plot and then
    deselecting the plot - it was not possible anymore to select the
    plot again on the worksheet.
* Tue Apr 14 2015 mailaender@opensuse.org
- update to version 2.0.2
* Sat Nov 15 2014 dmitry_r@opensuse.org
- Install documentation
* Tue Apr 22 2014 dmitry_r@opensuse.org
- labplot 2.0 doesn't support HDF5, NetCDF and Origin file formats,
  so disable not needed build requirements
* Sun Feb  2 2014 mailaender@opensuse.org
- update to 2.0.1
  * Fixed wrong scaling of legend's text labels in pdf-export
  * Fixed memory corruption in CartesianPlotDock that can lead to crashes
* Sun Jan 19 2014 mailaender@opensuse.org
- update to release 2.0.0
* Sun Dec 22 2013 mailaender@opensuse.org
- update to 2.0.0.beta2
* Wed Oct 23 2013 mailaender@opensuse.org
- packaged re-release of 2.0.0.beta1 to fix segfault on startup
- https://en.opensuse.org/SourceUrls
- use pkgconfig where possible
* Mon Oct 21 2013 toddrme2178@gmail.com
- Update to 2.0.0 beta 1
  * No changelog
* Sat Feb 16 2013 dmitry_r@opensuse.org
- qwt no longer needed
- use external liborigin library
* Tue Dec 25 2012 mailaender@opensuse.org
- update to version 2.0.0.alpha3
* Fri Aug 31 2012 scorot@free.fr
- fix libpng deps for SLE_11
* Fri Aug 31 2012 scorot@free.fr
- fix build for old qt4 with patch0
* Sun May  6 2012 idonmez@suse.com
- Fix factory build
* Tue Feb 14 2012 alinm.elena@gmail.com
- initial commit
